Reference: Reading
==================

This page documents the API for reading spectra from Bruker directories.
There are two functions to be used, although you should only really be using :func:`~penguins.read`.

.. currentmodule:: penguins

.. autofunction:: read

|v|

.. autofunction:: read_abs
